@@ -1,6 +1,6 @@
 /*
  *  DSH / dancer's shell or the distributed shell
- *  Copyright (C) 2001, 2002, 2003, 2004 Junichi Uekawa
+ *  Copyright (C) 2001, 2002, 2003, 2004, 2005 Junichi Uekawa
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -196,7 +196,7 @@ read_machinelist(linkedlist * machinelist, const char * listfile, const char*alt
 int print_version(void)
 {
   printf(_("Distributed Shell / Dancer\'s shell version %s \n"
-	 "Copyright 2001-2004 Junichi Uekawa, \n"
+	 "Copyright 2001-2005 Junichi Uekawa, \n"
 	 "distributed under the terms and conditions of GPL version 2\n\n"),
 	 VERSION);
   return 0;
@@ -578,6 +578,10 @@ parse_options ( int ac, char ** av)
   if (!(pipe_option & PIPE_OPTION_INPUT))
     open_devnull();		/* open /dev/null if no input pipe is required */
 
+
+  /* reverse the list, which is in reverse order, to make the right order */
+  machinelist = llreverse (machinelist);
+  
 				/* actually execute the code. */
   return do_shell(machinelist, rshcommandline_r);
 }
